@@ -241,9 +241,9 @@ getEntry Equiv { entries = mref} val = do
 
 
 
-{-| This function equates the two given elements. That is, it unions
-the equivalence classes of the two elements and combines their
-descriptor. The returned entry is the representative of the new
+{-| This function equates the two given (representative) elements. That
+is, it unions the equivalence classes of the two elements and combines
+their descriptor. The returned entry is the representative of the new
 equivalence class -}
 
 equateEntry :: (Monad m, Applicative m, Ord a) => Equiv s c a -> Entry s c a -> Entry s c a -> STT s m (Entry s c a)
@@ -264,7 +264,9 @@ equateEntry Equiv {combDesc = mkDesc} repx@(Entry rx) repy@(Entry ry) =
           writeSTRef ry dy{entryWeight = wx + wy, entryDesc = mkDesc chx chy}
           return repy
 
-      _ -> fail "error on `equateEntry`"
+      _ -> error "error on `equateEntry`"
+      -- this should not happen as this function is only called by
+      -- 'combineEntries', which always uses representative entries
   else return  repx
 
 combineEntries :: (Monad m, Applicative m, Ord a)
